@@ -164,7 +164,7 @@ def run(email, file, path):
     if email and success:
         msg = EmailMessage()
         msg.set_content(aggregate_output.decode('UTF-8'))
-        msg['Subject'] = f'[CRASHALYSER] Automated email: backtraces from core dumps on {platform.node()}'
+        msg['Subject'] = f'[CRASHALYSER] {platform.node()}: backtraces from {len(files_to_process)} core dump(s)'
         msg['From'] = merged_config['smtp.fromaddr']
         msg['To'] = email
 
